# Connect 4

This project will develop a connect 4 game with intelligent bot.

To install connect 4 on your machine use the command below

Required python version python 3.6 or above

```
pip install connect-4
```

To play the game run the command below after installation

```
connect_4
```
